<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\ButtonDropdown;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Event\Handlers\CreateEmails;
use EventPortal\Domain\Event\Handlers\SetAsUnpublished;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Domain\Team\Handlers\AssignTeam;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Enums\InertiaMethod;

Form::make('event.create')
    ->addSaveHandler(new CreateModel)
    ->addSaveHandler(new SetAsUnpublished)
    ->addSaveHandler(new AssignTeam)
    ->addSaveHandler(new CreateEmails)
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')
                    ->placeholder('Congress Meeting')
                    ->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder('http://google.com'),
                Select::make('Event type')
                    ->name('type')
                    ->placeholder('Please select an event type')
                    ->options([
                        Option::make('Congress'),
                        Option::make('Seminar'),
                    ]),
            ]),
            Section::make('Your team')->fields([
                Select::make('Assign a team')
                    ->name('team_id')
                    ->placeholder('Select a team')
                    ->options(Team::asOptions())
                    ->rules(['required']),
            ]),
            Section::make('Contact Details')->fields([
                Text::make('Phone')
                    ->placeholder('01234 567 890'),
                Text::make('Email')
                    ->placeholder('email@example.com')
                    ->rules(['nullable', 'email']),
            ]),
        ];
    })
    ->addActions(function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.index'),
            Button::make('Create Event')
                ->method(InertiaMethod::POST())
                ->route('admin.event.store'),
        ];
    });

Form::make('event.edit')
    ->addSaveHandler(new UpdateModel)
    ->addSaveHandler(new AssignTeam)
    ->addFields(function (Event $event) {
        return [
            Section::make('Key Details')->fields([
                Text::make('Name')->rules(['required']),
                Text::make('Url')
                    ->rules(['required'])
                    ->placeholder(config('app.url')),
                Select::make('Event type')
                    ->name('type')
                    ->placeholder('Please select an event type')
                    ->options([
                        Option::make('Congress'),
                        Option::make('Seminar'),
                    ]),
            ]),
            Section::make('Your team')->fields([
                Select::make('Assign a team')
                    ->name('team_id')
                    ->placeholder('Select a team')
                    ->options(Team::asOptions())
                    ->rules(['required'])
                    ->value($event->teamAsOption()),
            ]),
            Section::make('Contact Details')->fields([
                Text::make('Phone')->placeholder('01234 567 890'),
                Text::make('Email')->placeholder('email@example.com')->rules(['nullable', 'email']),
            ]),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.index'),
            Button::make('Update Event')
                ->method(InertiaMethod::POST())
                ->route('admin.event.update', ['event' => $event->id]),
        ];
    });

Form::make('event.show')
    ->addFields(function () {
        return [
            Section::make('Key Details')->fields([
                Display::make('Name'),
                Display::make('Url'),
                Display::make('Event type')->name('type'),
                Display::make('Status'),
            ]),
            Section::make('Your team')->fields([
                Display::make('Assign a team')->name('team_id'),
            ]),
            Section::make('Contact Details')->fields([
                Display::make('Phone'),
                Display::make('Email'),
            ]),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            ButtonDropdown::make('Transition')->actions($event->getTransitionActions()),
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.index'),
            Button::make('Edit Event')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.edit', ['event' => $event->id]),
        ];
    });
