<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Util\Notification\SystemNotification;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Support\Facades\Notification;
use Spatie\Snapshots\MatchesSnapshots;

class EmailSendTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_send_an_event_email_to_all_delegates()
    {
        Notification::fake();

        $event = factory(Event::class)->create([
            'name' => 'Hello World!',
        ]);
        factory(EventDelegate::class, 3)->create([
            'event_id' => $event->id,
        ]);
        $email = factory(EventEmail::class)
            ->state('invite')
            ->create([
                'event_id' => $event,
            ]);

        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.email.send', [
                'event' => $event,
                'email' => $email,
            ]))
            ->assertOk();

        Notification::assertSentTo(
            [$event->delegates->pluck('user')],
            SystemNotification::class,
            function (SystemNotification $notification) use ($event) {
                return $notification->subject === "You're invited to attend Hello World!"
                    && $notification->data['event']->id === $event->id;
            }
        );
    }
}
