<?php

namespace EventPortal\Tests\Unit\EventVenue;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventVenue;
use EventPortal\Domain\EventVenue\Actions\AssociateToEvent;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AssociateToEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function associate_to_event()
    {
        $event = factory(Event::class)->create();
        [$speakerA, $speakerB, $speakerC] = factory(Venue::class, 3)->create();

        (new AssociateToEvent)->execute($event, [
            $speakerA->id,
            $speakerC->id,
        ]);

        $this->assertEventHasVenues($event, [$speakerA, $speakerC]);
        $this->assertEventMissingVenue($event, $speakerB);
    }

    /** @test **/
    public function does_not_associate_more_than_once()
    {
        $event = factory(Event::class)->create();
        $speaker = factory(Venue::class)->create();

        (new AssociateToEvent)->execute($event, [$speaker->id]);
        (new AssociateToEvent)->execute($event, [$speaker->id]);

        $this->assertCount(1, EventVenue::all());
    }
}
